Introduction
------------

scrapenhl2 is a python package for scraping and manipulating NHL data pulled from the NHL website.

Contact
--------
`Twitter
<http://www.twitter.com/muneebalamcu>`_.

Change log
----------

9/24/17: Committed minimal structure.